@@ -1,5 +1,7 @@
 use std::cmp::Ordering;
 use std::fmt;
+#[cfg(debug_assertions)]
+use std::iter::FromIterator;
 use std::marker::PhantomData;
 use std::ops::Deref;
 use std::pin::Pin;
@@ -60,6 +62,7 @@ impl de::FromStream for NodeKey {
     async fn from_stream<D: de::Decoder>(cxt: (), decoder: &mut D) -> Result<Self, D::Error> {
         de::FromStream::from_stream(cxt, decoder)
             .map_ok(|(deleted, value)| Self { deleted, value })
+            .map_err(|e| de::Error::custom(format!("error decoding BTree node key: {}", e)))
             .await
     }
 }
@@ -79,8 +82,6 @@ impl<'en> en::IntoStream<'en> for NodeKey {
 #[cfg(debug_assertions)]
 impl fmt::Display for NodeKey {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        use std::iter::FromIterator;
-
         write!(
             f,
             "BTree node key: {}{}",
@@ -148,6 +149,7 @@ impl de::FromStream for Node {
                 children,
                 rebalance,
             })
+            .map_err(|e| de::Error::custom(format!("error decoding BTree node: {}", e)))
             .await
     }
 }
@@ -192,8 +194,6 @@ impl fmt::Debug for Node {
 #[cfg(debug_assertions)]
 impl fmt::Display for Node {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        use std::iter::FromIterator;
-
         if self.leaf {
             writeln!(f, "leaf node:")?;
         } else {
